cmd

Function cmd 

pub fn cmd(args: Args) -> Result<(Plan, BuiltPkgs)>
Build a pint package or workspace given a set of build args.

Returns the build Plan that was used, along with the set of packages that were built.